    @allure.step(title="浩瀚模块 - 更改充电桩权益状态-Y")
    @allure.step(title="浩瀚模块 - 更改充电桩权益状态-Y")
    def open_haohan_rights_update(self, params="$None$", _assert=True,  **kwargs):
        """
            url=/open/haohan/rights/update
                params: params : object :
                data : string : 加密数据
                params: headers : 请求头
        """
        params = self.get_value_choice(params, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.open_haohan_rights_update(**_kwargs)

        self.input_value.params = params

        if _assert is True:
            self.assert_open_haohan_rights_update(**_kwargs)
        elif _assert is not True:
            assert self.res.rsp.code == _assert or self.res.status_code == _assert, "校验code=%s不通过" % _assert
        return self.res





from service.app_t.app_t_assert import App_TAssert
from service.app_t import app_t_api

import allure


class App_TApiFun(App_TAssert):
    @allure.step(title="浩瀚模块-关联关系-Y")
    def open_haohan_relation_update(self, userId="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/open/haohan/relation/update
        params: userId :  : 用户ID（数据类型：String）"""
        userId = self.get_value_choice(userId, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.open_haohan_relation_update(**_kwargs)

        self._v_userId = userId

        if _assert is True:
            self.assert_open_haohan_relation_update(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="浩瀚模块 - 更改充电桩权益状态-Y")
    def open_haohan_rights_update(self, params="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/open/haohan/rights/update
        params: params : object :
        data : string : 加密数据"""
        params = self.get_value_choice(params, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.open_haohan_rights_update(**_kwargs)

        self._v_params = params

        if _assert is True:
            self.assert_open_haohan_rights_update(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="APP-用户签到")
    def points_pointsApp_signIn(self, userId="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/pointsApp/signIn
        params: userId :  : 用户ID"""
        userId = self.get_value_choice(userId, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_pointsApp_signIn(**_kwargs)

        self._v_userId = userId

        if _assert is True:
            self.assert_points_pointsApp_signIn(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="APP - 查看我的积分")
    def points_pointsApp_myPoints(self, userId="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/pointsApp/myPoints
        params: userId :  : 用户ID"""
        userId = self.get_value_choice(userId, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_pointsApp_myPoints(**_kwargs)

        self._v_userId = userId

        if _assert is True:
            self.assert_points_pointsApp_myPoints(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="APP - 总积分查询")
    def points_pointsApp_myPointsTotal(self, userId="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/pointsApp/myPointsTotal
        params: userId :  : 用户ID"""
        userId = self.get_value_choice(userId, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_pointsApp_myPointsTotal(**_kwargs)

        self._v_userId = userId

        if _assert is True:
            self.assert_points_pointsApp_myPointsTotal(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="查看积分明细- - 积分流水分页查询")
    def points_points_flowDetail(self, userId="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/points/flowDetail
        params: userId :  : 用户ID"""
        userId = self.get_value_choice(userId, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_points_flowDetail(**_kwargs)

        self._v_userId = userId

        if _assert is True:
            self.assert_points_points_flowDetail(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="积分统计-分页查询积分")
    def points_points_page(self, current=1, size=10, beforeTime="$None$", endTime="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/points/page
        params: current :  :
        params: size :  :
        params: beforeTime :  :
        params: endTime :  :"""
        if self.has_true(locals()) and not self._list_beforeTime:
            self.points_points_page(_assert=False)

        beforeTime = self.get_list_choice(beforeTime, self._list_beforeTime)
        endTime = self.get_list_choice(endTime, self._list_endTime)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_points_page(**_kwargs)

        self._list_beforeTime = self.get_res_value_list('beforeTime')
        self._list_endTime = self.get_res_value_list('endTime')
        self._v_beforeTime = beforeTime
        self._v_endTime = endTime

        if _assert is True:
            self.assert_points_points_page(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="积分统计 - 导出")
    def points_points_download(self, current=1, size=10, beforeTime="$None$", endTime="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/points/download
        params: current :  :
        params: size :  :
        params: endTime :  :
        params: beforeTime :  :"""
        beforeTime = self.get_value_choice(beforeTime, list_or_dict=None)
        endTime = self.get_value_choice(endTime, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_points_download(**_kwargs)

        self._v_beforeTime = beforeTime
        self._v_endTime = endTime

        if _assert is True:
            self.assert_points_points_download(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res

    @allure.step(title="用户中心-兑换明细 - 分页查询")
    def points_points_convertDetail(self, userId="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/points/points/convertDetail
        params: userId :  : 用户ID"""
        userId = self.get_value_choice(userId, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = app_t_api.points_points_convertDetail(**_kwargs)

        self._v_userId = userId

        if _assert is True:
            self.assert_points_points_convertDetail(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res


if __name__ == '__main__':
    s = App_TApiFun()




import allure

from service.app_t.app_t_sql import App_TSql


class App_TAssert(App_TSql):

    @allure.step(title="接口返回结果校验")
    def assert_open_haohan_relation_update(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_open_haohan_relation_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_open_haohan_rights_update(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_open_haohan_rights_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["params"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_pointsApp_signIn(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_pointsApp_signIn(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_pointsApp_myPoints(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_pointsApp_myPoints(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_pointsApp_myPointsTotal(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_pointsApp_myPointsTotal(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_points_flowDetail(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_points_flowDetail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_points_page(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_points_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["beforeTime", "endTime"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_points_download(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_points_download(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["beforeTime", "endTime"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_points_points_convertDetail(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_points_points_convertDetail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId"])
        assert True, "数据比较不一致"


if __name__ == '__main__':
    s = App_TAssert()




import pytest
import allure

from service.app_t.app_t_api_fun import App_TApiFun


@allure.epic("针对单api的测试")
@allure.feature("场景：")
class TestApi:
    def setup(self):
        self.f = App_TApiFun()

    @pytest.mark.skip("待维护")
    @allure.step(title="浩瀚模块-关联关系-Y")
    def test_open_haohan_relation_update(self):
        self.f.open_haohan_relation_update()


    @pytest.mark.skip("待维护")
    @allure.step(title="浩瀚模块 - 更改充电桩权益状态-Y")
    def test_open_haohan_rights_update(self):
        self.f.open_haohan_rights_update()


    @pytest.mark.skip("待维护")
    @allure.step(title="APP-用户签到")
    def test_points_pointsApp_signIn(self):
        self.f.points_pointsApp_signIn()


    @pytest.mark.skip("待维护")
    @allure.step(title="APP - 查看我的积分")
    def test_points_pointsApp_myPoints(self):
        self.f.points_pointsApp_myPoints()


    @pytest.mark.skip("待维护")
    @allure.step(title="APP - 总积分查询")
    def test_points_pointsApp_myPointsTotal(self):
        self.f.points_pointsApp_myPointsTotal()


    @pytest.mark.skip("待维护")
    @allure.step(title="查看积分明细- - 积分流水分页查询")
    def test_points_points_flowDetail(self):
        self.f.points_points_flowDetail()


    @pytest.mark.skip("待维护")
    @allure.step(title="积分统计-分页查询积分")
    def test_points_points_page(self):
        self.f.points_points_page()


    @pytest.mark.skip("待维护")
    @allure.step(title="积分统计 - 导出")
    def test_points_points_download(self):
        self.f.points_points_download()


    @pytest.mark.skip("待维护")
    @allure.step(title="用户中心-兑换明细 - 分页查询")
    def test_points_points_convertDetail(self):
        self.f.points_points_convertDetail()





import requests

from huhk.unit_fun import FunBase
from huhk import admin_host


class DemoFun(FunBase):
    def __init__(self):
        super().__init__()
        self.res = None
        self._v_mobile = None

    def run_mysql(self, sql_str):
        # id是后台http://47.96.124.102/admin 项目数据库链接的id
        out = requests.post(admin_host + "/sql/running_sql/", json={"id": 1, "sql_str": sql_str}).json()
        if out.get("code") == "0000":
            return out.get("data")
        else:
            assert False, sql_str + str(out.get("msg"))


if __name__ == '__main__':
    f = DemoFun()
    out = f.run_mysql("SELECT * FROM `t_accept_log`  LIMIT 1;")
    print(out)




import allure

from service.demo import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/demo")
def demo(mobile=None, headers=None, **kwargs):
    """
    发送手机验证码
    up_time=1657087679

    params: mobile :  : 用户电话号码
    params: headers : 请求
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : null : 
    """
    _method = "GET"
    _url = "/common/common/sendSmsCode"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "mobile": mobile,  # 用户电话号码
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)




import allure

from service.demo.demo_sql import DemoSql


class DemoAssert(DemoSql):

    @allure.step(title="接口返回结果校验")
    def assert_demo(self, **kwargs):
        assert self.res.rsp.code in (0, 200), self.res.rsp.msg
        # out = self.sql_demo(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["mobile"])
        assert True, "数据比较不一致"


if __name__ == '__main__':
    s = DemoAssert()




from service.demo.demo_assert import DemoAssert
from service.demo import demo_api

import allure


class DemoApiFun(DemoAssert):
    @allure.step(title="发送手机验证码")
    def demo(self, mobile="$None$", headers="$None$", _assert=True,  **kwargs):
        """url=/common/common/sendSmsCode
        params: mobile :  : 用户电话号码"""
        mobile = self.get_value_choice(mobile, list_or_dict=None)

        _kwargs = self.get_kwargs(locals())
        self.res = demo_api.demo(**_kwargs)

        self._v_mobile = mobile

        if _assert is True:
            self.assert_demo(**_kwargs)
        elif _assert is not False:
            assert self.res.rsp.code == _assert, "校验code=%s不通过" % _assert
        return self.res


if __name__ == '__main__':
    s = DemoApiFun()

